package VMOMI::DiagnosticPartitionStorageType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
